/* jshint 
    browser: true, jquery: true, node: true,
    bitwise: true, camelcase: false, curly: true, eqeqeq: true, esversion: 6, expr: true, forin: true, immed: true, indent: 4, latedef: false, newcap: true, noarg: true, noempty: true, nonew: true, quotmark: single, regexdash: true, strict: true, sub: true, trailing: true, undef: true, unused: vars, white: true
*/

'use strict';

const crypto = require('crypto');
const nightmare = require('nightmare');
const networkInterfaces = require('os').networkInterfaces();

const ip = networkInterfaces['Local Area Connection'].filter(x => x.family === 'IPv4')[0].address;

module.exports = (email, urls, options, returnError) => {
	
	if (typeof options === 'function') {
		returnError = options;
	}

	if (typeof urls === 'string') {
		urls = [urls];
	}

	options = options || {};

	options.showBrowser = options.showBrowser || false;
	options.refreshDidNotFixIt = options.refreshDidNotFixIt || false;
	options.details = options.details || '';
	options.dateTime = options.dateTime || new Date().toLocaleDateString() + ' ' + new Date().toLocaleTimeString();

	const nightmareOptions = {
		show: options.showBrowser,
		webPreferences: { partition: crypto.randomBytes(4).readUInt32LE(0).toString()}
	};

	const browser = nightmare(nightmareOptions);
	
	browser.goto('https://connectwise.sharepoint.com/corp/IT/Lists/NetworkResponse/AllItems.aspx')
		.wait('#cred_userid_inputtext')
		.type('#cred_userid_inputtext', email)
		.click('#cred_sign_in_button')
		.wait(500)
		.exists('#aad_account_tile')
		.then(exists => {
			if (exists) {
				browser.click('#aad_account_tile');
			}

			submitForms();
		});

	function submitForms() {

		browser.wait('#idHomePageNewItem');

		urls.forEach(url => {
			browser.click('#idHomePageNewItem')
				.wait('#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_B8')
				.type('#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_T1', ip)
				.type('#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_T2', options.dateTime)
				.type('#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_T3', url)
				.click(options.refreshDidNotFixIt ? '#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_O5' : '#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_O4')
				.type('#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_T6', options.details)
				.click('#ctl00_ctl46_g_d7c7c005_0dee_4ac6_b3c7_baf731cf190c_FormControl0_V1_I1_B8')
				.wait('#idHomePageNewItem');
		});

		browser.end()
			.catch(error => {
				returnError && returnError(error);
			});
	}

};